Repo of the Unknown - #2: Ten days later

# #2: Ten days later

- Nov 05, 2023
- Categories: Blog
- Tags: #python #balladeer #game jam

## Hesitation

It was Wednesday before I wrote any code.

There had been scant opportunity to do so, and in any case, I did not know where to start. Instead, over the first few days there started to form in my mind's eye a flicker of an opening sequence. Rhythmic, like a scene from a road movie. The darkened profile of a passenger from the inside of a speeding vehicle.

A new possibility for the word repo. Two characters in a van on the way to a job. I began to imagine some dialogue. Which is the player; the driver or the mate?

We have to give the player a few moments to settle in. We want some workmanlike banter to reveal the initial premise. Some low-stakes decisions to kick off the adventure.

That's when I realised the benefit of a dialogue tree. And since at the time Balladeer didn't offer such a feature, I spent the rest of the week building one.

It was the best thing that could have happened. I'm very pleased with the new Interaction system. So thankyou to the Python Game Jam.